/**************************
* Application
**************************/
PM = Ember.Application.create({
	rate: 100,
	ready: function(){
		this._super();
		console.log('Application loaded');
	},
	loadView: function(view){
		console.log('loading view');
		var me = this;
		var templateName = $(view.currentTarget).data('view');
		var viewPath = 'views/%@.txt'.fmt(templateName);

		$.ajax({
			url: viewPath,
			success: function (template) {
				console.log('view loaded from URL');
				if (Ember.TEMPLATES[templateName]) {
					console.log("template " + templateName + " already injected to the page");
				} else {
					Ember.TEMPLATES[templateName] = Ember.Handlebars.compile(template);
				};
				me.insertView(templateName);
			},
			error: function (jqXHR, textStatus, errorThrown) {
				console.log(jqXHR, textStatus, errorThrown);
			}
		});
	},
	insertView: function(view){
		console.log('view injected into page');
		// PM.addClientView.appendTo('body');
		PM[view + 'View'].appendTo('body');
	},
	closeWindow: function(view){
		console.log('removing view');
		var templateName = (view.context) ? view.context.get('templateName') + 'View' : view.get('templateName') + 'View'
		console.log(templateName);
		PM[templateName].remove()
		$('.overlay').remove();
	}
});

/**************************
* Models
**************************/
PM.Client = Ember.Object.extend({
	id: null,
	client: null,
	projects: []
});

PM.Project = Ember.Object.extend({
	id: null,
	title: null,
	totalHours: null,
	cost: function(){
		return this.get('totalHours') * PM.get('rate');
	}.property('totalHours')
});

/**************************
* Views
**************************/
PM.addClientView = Ember.View.create({
	templateName: 'addClient',
	classNames: 'overlay',
	client: null,
	addClientSubmit: function(e){
		e.preventDefault();
		console.log('new client added');
		var client = PM.Client.create({
			client: e.context.get('client')
		});
		PM.clientsArray.pushObject(client);
		PM.closeWindow(this);
		this.set('client','');
	}
});
PM.addProjectView = Ember.View.create({
	templateName: 'addProject',
	classNames: 'overlay',
	project: null,
	totalHours: null,
	addProjectSubmit: function(e){
		e.preventDefault();
		console.log('new project added');
		var project = PM.Project.create({
			title: e.context.get('title'),
			totalHours: e.context.get('totalHours')
		});
		PM.clientsArray.pushObject(client);
		// PM.closeWindow(this);
	}
});

/**************************
* Controllers
**************************/
PM.clientsArray = Ember.ArrayController.create({
	content: [],
	currentClient: null,
	init: function(){
		this._super();
		console.log('clientsArray loaded');
		this.loadClients();
	},
	loadClients: function(){
		var me = this;
		$.ajax({
			url: 'data/pm.txt',
			dataType: 'json',
			success: function (data) {
				console.log('pm data loaded');
				$(data).each(function(i,c){
					var projects = [];
					$(c.projects).each(function(i,p){
						var project = PM.Project.create({
										title: p.title,
										totalHours: p.totalHours,
									});
						projects.push(project);
					});
					var client = PM.Client.create({
									client: c.client,
									projects: projects
								});
					me.pushObject(client);
				});
			},
			error: function (jqXHR, textStatus, errorThrown) {
				console.log(jqXHR, textStatus, errorThrown);
			}
		});
	},
	loadProjects: function(view){
		console.log('loading projects');
		this.currentClient = view.context;
		PM.projectsArray.set('content', []);
		PM.projectsArray.pushObjects(view.context.get('projects'));
	}
});

PM.projectsArray = Ember.ArrayController.create();